@@ -7,7 +7,6 @@
 #include "utils.h"
 #include "stream.h"
 #include "resolve.h"
-#include "check.h"
 
 namespace rclock {
 
@@ -26,47 +25,6 @@ resolve_previous_day_ymd(const date::year_month_day& x) {
   return x.year() / x.month() / date::last;
 }
 
-template <enum component Component>
-inline void check_range(const int& value, const char* arg) {
-  clock_abort("Unimplemented range check");
-}
-template <>
-inline void check_range<component::year>(const int& value, const char* arg) {
-  check_range_year(value, arg);
-}
-template <>
-inline void check_range<component::month>(const int& value, const char* arg) {
-  check_range_month(value, arg);
-}
-template <>
-inline void check_range<component::day>(const int& value, const char* arg) {
-  check_range_day(value, arg);
-}
-template <>
-inline void check_range<component::hour>(const int& value, const char* arg) {
-  check_range_hour(value, arg);
-}
-template <>
-inline void check_range<component::minute>(const int& value, const char* arg) {
-  check_range_minute(value, arg);
-}
-template <>
-inline void check_range<component::second>(const int& value, const char* arg) {
-  check_range_second(value, arg);
-}
-template <>
-inline void check_range<component::millisecond>(const int& value, const char* arg) {
-  check_range_millisecond(value, arg);
-}
-template <>
-inline void check_range<component::microsecond>(const int& value, const char* arg) {
-  check_range_microsecond(value, arg);
-}
-template <>
-inline void check_range<component::nanosecond>(const int& value, const char* arg) {
-  check_range_nanosecond(value, arg);
-}
-
 } // namespace detail
 
 class y
@@ -83,18 +41,11 @@ public:
 
   std::ostringstream& stream(std::ostringstream&, r_ssize i) const NOEXCEPT;
 
-  bool ok(r_ssize i) const NOEXCEPT;
-
   void add(const date::years& x, r_ssize i) NOEXCEPT;
 
   void assign_year(const date::year& x, r_ssize i) NOEXCEPT;
   void assign_na(r_ssize i) NOEXCEPT;
 
-  void resolve(r_ssize i, const enum invalid type);
-
-  template <component Component>
-  void check_range(const int& value, const char* arg) const;
-
   date::year to_year(r_ssize i) const NOEXCEPT;
   cpp11::writable::list to_list() const;
 };
@@ -111,16 +62,12 @@ public:
 
   std::ostringstream& stream(std::ostringstream&, r_ssize i) const NOEXCEPT;
 
-  bool ok(r_ssize i) const NOEXCEPT;
-
   void add(const date::months& x, r_ssize i) NOEXCEPT;
 
   void assign_month(const date::month& x, r_ssize i) NOEXCEPT;
   void assign_year_month(const date::year_month& x, r_ssize i) NOEXCEPT;
   void assign_na(r_ssize i) NOEXCEPT;
 
-  void resolve(r_ssize i, const enum invalid type);
-
   date::year_month to_year_month(r_ssize i) const NOEXCEPT;
   cpp11::writable::list to_list() const;
 };
@@ -138,14 +85,12 @@ public:
 
   std::ostringstream& stream(std::ostringstream&, r_ssize i) const NOEXCEPT;
 
-  bool ok(r_ssize i) const NOEXCEPT;
-
   void assign_day(const date::day& x, r_ssize i) NOEXCEPT;
   void assign_year_month_day(const date::year_month_day& x, r_ssize i) NOEXCEPT;
   void assign_sys_time(const date::sys_time<date::days>& x, r_ssize i) NOEXCEPT;
   void assign_na(r_ssize i) NOEXCEPT;
 
-  void resolve(r_ssize i, const enum invalid type);
+  void resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call);
 
   date::sys_time<date::days> to_sys_time(r_ssize i) const NOEXCEPT;
   date::year_month_day to_year_month_day(r_ssize i) const NOEXCEPT;
@@ -170,7 +115,7 @@ public:
   void assign_sys_time(const date::sys_time<std::chrono::hours>& x, r_ssize i) NOEXCEPT;
   void assign_na(r_ssize i) NOEXCEPT;
 
-  void resolve(r_ssize i, const enum invalid type);
+  void resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call);
 
   date::sys_time<std::chrono::hours> to_sys_time(r_ssize i) const NOEXCEPT;
   cpp11::writable::list to_list() const;
@@ -195,7 +140,7 @@ public:
   void assign_sys_time(const date::sys_time<std::chrono::minutes>& x, r_ssize i) NOEXCEPT;
   void assign_na(r_ssize i) NOEXCEPT;
 
-  void resolve(r_ssize i, const enum invalid type);
+  void resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call);
 
   date::sys_time<std::chrono::minutes> to_sys_time(r_ssize i) const NOEXCEPT;
   cpp11::writable::list to_list() const;
@@ -221,7 +166,7 @@ public:
   void assign_sys_time(const date::sys_time<std::chrono::seconds>& x, r_ssize i) NOEXCEPT;
   void assign_na(r_ssize i) NOEXCEPT;
 
-  void resolve(r_ssize i, const enum invalid type);
+  void resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call);
 
   date::sys_time<std::chrono::seconds> to_sys_time(r_ssize i) const NOEXCEPT;
   cpp11::writable::list to_list() const;
@@ -249,7 +194,7 @@ public:
   void assign_sys_time(const date::sys_time<Duration>& x, r_ssize i) NOEXCEPT;
   void assign_na(r_ssize i) NOEXCEPT;
 
-  void resolve(r_ssize i, const enum invalid type);
+  void resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call);
 
   date::sys_time<Duration> to_sys_time(r_ssize i) const NOEXCEPT;
   cpp11::writable::list to_list() const;
@@ -293,13 +238,6 @@ y::stream(std::ostringstream& os, r_ssize i) const NOEXCEPT
   return os;
 }
 
-inline
-bool
-y::ok(r_ssize i) const NOEXCEPT
-{
-  return true;
-}
-
 inline
 void
 y::add(const date::years& x, r_ssize i) NOEXCEPT
@@ -321,21 +259,6 @@ y::assign_na(r_ssize i) NOEXCEPT
   year_.assign_na(i);
 }
 
-inline
-void
-y::resolve(r_ssize i, const enum invalid type)
-{
-  // Never invalid
-}
-
-template <component Component>
-inline
-void
-y::check_range(const int& value, const char* arg) const
-{
-  detail::check_range<Component>(value, arg);
-}
-
 inline
 date::year
 y::to_year(r_ssize i) const NOEXCEPT
@@ -378,13 +301,6 @@ ym::stream(std::ostringstream& os, r_ssize i) const NOEXCEPT
   return os;
 }
 
-inline
-bool
-ym::ok(r_ssize i) const NOEXCEPT
-{
-  return true;
-}
-
 inline
 void
 ym::add(const date::months& x, r_ssize i) NOEXCEPT
@@ -415,13 +331,6 @@ ym::assign_na(r_ssize i) NOEXCEPT
   month_.assign_na(i);
 }
 
-inline
-void
-ym::resolve(r_ssize i, const enum invalid type)
-{
-  // Never invalid
-}
-
 inline
 date::year_month
 ym::to_year_month(r_ssize i) const NOEXCEPT
@@ -464,13 +373,6 @@ ymd::stream(std::ostringstream& os, r_ssize i) const NOEXCEPT
   return os;
 }
 
-inline
-bool
-ymd::ok(r_ssize i) const NOEXCEPT
-{
-  return to_year_month_day(i).ok();
-}
-
 inline
 void
 ymd::assign_day(const date::day& x, r_ssize i) NOEXCEPT
@@ -505,7 +407,7 @@ ymd::assign_na(r_ssize i) NOEXCEPT
 
 inline
 void
-ymd::resolve(r_ssize i, const enum invalid type)
+ymd::resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call)
 {
   const date::year_month_day elt = to_year_month_day(i);
 
@@ -534,7 +436,7 @@ ymd::resolve(r_ssize i, const enum invalid type)
     break;
   }
   case invalid::error: {
-    rclock::detail::resolve_error(i);
+    rclock::detail::resolve_error(i, call);
   }
   }
 }
@@ -616,7 +518,7 @@ ymdh::assign_na(r_ssize i) NOEXCEPT
 
 inline
 void
-ymdh::resolve(r_ssize i, const enum invalid type)
+ymdh::resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call)
 {
   const date::year_month_day elt = to_year_month_day(i);
 
@@ -654,7 +556,7 @@ ymdh::resolve(r_ssize i, const enum invalid type)
     break;
   }
   case invalid::error: {
-    rclock::detail::resolve_error(i);
+    rclock::detail::resolve_error(i, call);
   }
   }
 }
@@ -730,7 +632,7 @@ ymdhm::assign_na(r_ssize i) NOEXCEPT
 
 inline
 void
-ymdhm::resolve(r_ssize i, const enum invalid type)
+ymdhm::resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call)
 {
   const date::year_month_day elt = to_year_month_day(i);
 
@@ -771,7 +673,7 @@ ymdhm::resolve(r_ssize i, const enum invalid type)
     break;
   }
   case invalid::error: {
-    rclock::detail::resolve_error(i);
+    rclock::detail::resolve_error(i, call);
   }
   }
 }
@@ -848,7 +750,7 @@ ymdhms::assign_na(r_ssize i) NOEXCEPT
 
 inline
 void
-ymdhms::resolve(r_ssize i, const enum invalid type)
+ymdhms::resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call)
 {
   const date::year_month_day elt = to_year_month_day(i);
 
@@ -892,7 +794,7 @@ ymdhms::resolve(r_ssize i, const enum invalid type)
     break;
   }
   case invalid::error: {
-    rclock::detail::resolve_error(i);
+    rclock::detail::resolve_error(i, call);
   }
   }
 }
@@ -977,7 +879,7 @@ ymdhmss<Duration>::assign_na(r_ssize i) NOEXCEPT
 template <typename Duration>
 inline
 void
-ymdhmss<Duration>::resolve(r_ssize i, const enum invalid type)
+ymdhmss<Duration>::resolve(r_ssize i, const enum invalid type, const cpp11::sexp& call)
 {
   const date::year_month_day elt = to_year_month_day(i);
 
@@ -1024,7 +926,7 @@ ymdhmss<Duration>::resolve(r_ssize i, const enum invalid type)
     break;
   }
   case invalid::error: {
-    rclock::detail::resolve_error(i);
+    rclock::detail::resolve_error(i, call);
   }
   }
 }
